:tocdepth: 2

============================================
API of Hardware Introspection for Bare Metal
============================================

.. rest_expand_all::

.. include:: introspection-api-versions.inc
.. include:: introspection-api-v1-introspection.inc
.. include:: introspection-api-v1-continue.inc
.. include:: introspection-api-v1-rules.inc
